<?php


class YooTranslateTransform
{

    /**
     * Transform callback.
     * Use for Front-end translation
     * @since 1.12 add newsletter translation (message and redirect)
     * @update 1.16 add search system code to allow parsing for other language by yootheme_save_page
     *
     * @param object $node
     * @param array  $params
     */
    public function __invoke($node, array $params)
    {
        /**
         * @var $type
         */
        extract($params);
        $falangyootheme = FalangYOOTHeme::getInstance();

        $currentLanguage = $falangyootheme->get_current_language();

        //search managed by filter yootheme_save_page
        if (isset($params['search']) && $params['search'] ==  true){
            $locale = $params['lang'];
            $currentLanguage = FALANG()->model->get_language_by_locale( $locale );
        }

        $elts = $falangyootheme->getElements();
        //supported element translation
        if (isset($elts[$node->type])){
            foreach ($elts[$node->type]['fields'] as $field){
                $translated_field_name =  $falangyootheme->getTranslatedFieldName($field,$currentLanguage);

                if (isset($node->props[$translated_field_name]) && !empty($node->props[$translated_field_name])){

                    $node->props[$field] = $node->props[$translated_field_name];
                    unset($node->props[$translated_field_name]);
                }

                //manage newsletter provider for message and redirect
                if ($node->type == 'newsletter' && ($field == 'provider.message' || $field == 'provider.redirect' )){
                    $translated_field_name = str_replace('provider.','',$translated_field_name);
                    $field = str_replace('provider.','',$field);
                    if (isset($node->props['provider']) && isset($node->props['provider']->{$translated_field_name}) && !empty($node->props['provider']->{$translated_field_name})){
                        $node->props['provider']->{$field} = $node->props['provider']->{$translated_field_name};
                    }
                }

            }
        }
    }

    /**
     * Add extra field to each elements.
     * Use for backend  translation
     *
     * @since 1.1 allow source to be dynamic
     * @update 1.3 fix notice if elements field don't exist see on gridpro flart
     * @update 1.6 add message for pro supported elements
     * @update 1.13 add debounce to decrease refresh on content translation edition
     * @update 1.14 add tab title with a domain to be translatable
     * @update 1.15 change debounce delay to 500 - Fix save button display delay
     *
     * @param object $node
     * @param array  $params
     */
    public static function initSource(array $type)
    {

        if (isset($type)){
            //TODO change this
            $falangyootheme = FalangYOOTHeme::getInstance();
            $elts = $falangyootheme->getElements();
            $falang_tab_title = __('Falang','falang-for-yootheme');
            if (isset($elts[$type['name']])){
                //get fileds to translate for this elements
                $fields = $elts[$type['name']]['fields'];
                //$languages = yootranslatetransform::getLanguages(false);
                //TODO change this
                $languages = $falangyootheme->get_languages_list(array( 'hide_default' => true ) );
                $newFieldList = array();
                foreach ($languages as $language){
                    foreach ($fields as $field){
                        //check the field in case of extra elemnts change
                        if (!isset($type['fields'][$field])){continue;}
                        //add new fieldtype
                        $newFieldType = $type['fields'][$field];
                        //countdown don't have label define for hours, minutes... only days
                        //yooessential markdown too
                        //put empty label in this case
                        if (!isset($newFieldType['label'])) {$newFieldType['label'] = '';}

                        $newFieldType['label'] = $falangyootheme->getTranslatedFieldLabel($newFieldType['label'], $language);
                        if (isset($newFieldType['source'])) {
                            //$newFieldType['source'] = false;//need to be keep to allow dynamic
                        }
                        //change refresh for content (work only on content)
                        if ($field == 'content' ){
                            $newFieldType['attrs'] = ["debounce" => 500];
                        }
                        //add new fieldtype
                        $type['fields'][$falangyootheme->getTranslatedFieldName($field, $language)] = $newFieldType;

                        $newFieldList[] = $falangyootheme->getTranslatedFieldName($field, $language);

                        //add new field to Falang tab
                    }

                }
                $newfield = array('title'=> $falang_tab_title,'fields' => $newFieldList);
                $type['fieldset']['default']['fields'][] = $newfield;
            }
            //display message on Lite version
            if( !$falangyootheme->is_falang_for_yootheme_pro_activated()){
                $elts_pro = $falangyootheme->getProElements();
                if (isset($elts_pro[$type['name']])){
                    $fieldmessage['falang_pro_message'] = [
                        'label' => esc_html__('Falang Message','falang-for-yootheme'),
                        'source' => false,
                        'type' => 'none',
                        'description' => esc_html__('The Falang for YOOTheme Pro is needed to translate this element.','falang-for-yootheme')
                    ];
                    $newfield = array('title'=> $falang_tab_title,'fields' => $fieldmessage);
                    $type['fieldset']['default']['fields'][] = $newfield;
                }
            }
        }
        return $type;
    }

}
